@@ -450,11 +450,7 @@ get_time (const gchar* format)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 dialog_disposed (GObject *obj, gpointer dialog_pointer)
-#else
-dialog_destroyed (GtkObject *obj, gpointer dialog_pointer)
-#endif
 {
 	pluma_debug (DEBUG_PLUGINS);
 
@@ -716,9 +712,7 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 
 	pluma_debug (DEBUG_PLUGINS);
 
-	dialog = g_new0 (TimeConfigureDialog, 1);
-
-	dialog->dialog = gtk_dialog_new_with_buttons (_("Configure insert date/time plugin..."),
+	GtkWidget *dlg = gtk_dialog_new_with_buttons (_("Configure insert date/time plugin..."),
 						      NULL,
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_STOCK_CANCEL,
@@ -729,6 +723,11 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 						      GTK_RESPONSE_HELP,
 						      NULL);
 
+	g_return_val_if_fail (dlg != NULL, NULL);
+
+	dialog = g_new0 (TimeConfigureDialog, 1);
+	dialog->dialog = dlg;
+
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
@@ -737,7 +736,6 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 					5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog))), 6);
 
-	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
 	data_dir = pluma_plugin_get_data_dir (PLUMA_PLUGIN (plugin));
 	ui_file = g_build_filename (data_dir, "pluma-time-setup-dialog.ui", NULL);
@@ -770,9 +768,6 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 	}
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog->dialog), FALSE);
-#endif
 
 	sf = get_selected_format (plugin);
 	create_formats_list (dialog->list, sf, plugin);
@@ -836,13 +831,8 @@ get_configure_dialog (PlumaTimePlugin *plugin)
 			  G_CALLBACK (configure_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "dispose",
 			  G_CALLBACK (dialog_disposed),
-#else
-			  "destroy",
-			  G_CALLBACK (dialog_destroyed),
-#endif
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
@@ -936,9 +926,6 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			gtk_window_group_add_window (wg, GTK_WINDOW (err_dialog));
 
 		gtk_window_set_resizable (GTK_WINDOW (err_dialog), FALSE);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-		gtk_dialog_set_has_separator (GTK_DIALOG (err_dialog), FALSE);
-#endif
 		gtk_dialog_set_default_response (GTK_DIALOG (err_dialog), GTK_RESPONSE_OK);
 
 		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (err_dialog))),
@@ -1006,13 +993,8 @@ get_choose_format_dialog (GtkWindow                 *parent,
 			  G_CALLBACK (choose_format_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "dispose",
 			  G_CALLBACK (dialog_disposed),
-#else
-			  "destroy",
-			  G_CALLBACK (dialog_destroyed),
-#endif
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
