@@ -49,10 +49,6 @@
 #include "pluma-marshal.h"
 #include "pluma-window.h"
 
-#ifdef BUILD_SPINNER
-#include "pluma-spinner.h"
-#endif
-
 #define AFTER_ALL_TABS -1
 #define NOT_IN_APP_WINDOWS -2
 
@@ -100,11 +96,7 @@ enum
 static guint signals[LAST_SIGNAL] = { 0 };
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 pluma_notebook_dispose (GObject *object)
-#else
-pluma_notebook_destroy (GtkObject *object)
-#endif
 {
 	PlumaNotebook *notebook = PLUMA_NOTEBOOK (object);
 
@@ -124,28 +116,17 @@ pluma_notebook_destroy (GtkObject *object)
 		notebook->priv->destroy_has_run = TRUE;
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	G_OBJECT_CLASS (pluma_notebook_parent_class)->dispose (object);
-#else
-	GTK_OBJECT_CLASS (pluma_notebook_parent_class)->destroy (object);
-#endif
 }
 
 static void
 pluma_notebook_class_init (PlumaNotebookClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
-#endif
 	GtkNotebookClass *notebook_class = GTK_NOTEBOOK_CLASS (klass);
 
 	object_class->finalize = pluma_notebook_finalize;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	object_class->dispose = pluma_notebook_dispose;
-#else
-	gtkobject_class->destroy = pluma_notebook_destroy;
-#endif
 
 	notebook_class->change_current_page = pluma_notebook_change_current_page;
 
@@ -261,13 +242,6 @@ find_tab_num_at_pos (PlumaNotebook *notebook,
 
 	tab_pos = gtk_notebook_get_tab_pos (GTK_NOTEBOOK (notebook));
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	if (GTK_NOTEBOOK (notebook)->first_tab == NULL)
-	{
-		return AFTER_ALL_TABS;
-	}
-#endif
-
 	/* For some reason unfullscreen + quick click can
 	   cause a wrong click event to be reported to the tab */
 	if (!is_in_notebook_window (notebook, abs_x, abs_y))
@@ -285,28 +259,16 @@ find_tab_num_at_pos (PlumaNotebook *notebook,
 		tab = gtk_notebook_get_tab_label (nb, page);
 		g_return_val_if_fail (tab != NULL, AFTER_ALL_TABS);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		if (!gtk_widget_get_mapped (tab))
-#else
-		if (!GTK_WIDGET_MAPPED (GTK_WIDGET (tab)))
-#endif
 		{
 			++page_num;
 			continue;
 		}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gdk_window_get_origin (GDK_WINDOW (gtk_widget_get_window (tab)),
-#else
-		gdk_window_get_origin (GDK_WINDOW (tab->window),
-#endif
 				       &x_root, &y_root);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gtk_widget_get_allocation(tab, &allocation);
-#else
-		allocation = tab->allocation;
-#endif
 
 		max_x = x_root + allocation.x + allocation.width;
 		max_y = y_root + allocation.y + allocation.height;
@@ -689,11 +651,7 @@ pluma_notebook_new (void)
 
 static void
 pluma_notebook_switch_page_cb (GtkNotebook     *notebook,
-#if GTK_CHECK_VERSION (3, 0, 0)
                                GtkWidget       *page,
-#else
-                               GtkNotebookPage *page,
-#endif
                                guint            page_num,
                                gpointer         data)
 {
