@@ -132,11 +132,7 @@ pluma_utils_menu_position_under_widget (GtkMenu  *menu,
 
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_get_allocation (widget, &allocation);
-#else
-	allocation = widget->allocation;
-#endif
 
 	if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 	{
@@ -241,11 +237,7 @@ pluma_dialog_add_button (GtkDialog   *dialog,
 	button = pluma_gtk_button_new_with_stock_icon (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_can_default (button, TRUE);
-#else
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-#endif
 
 	gtk_widget_show (button);
 
@@ -911,18 +903,10 @@ pluma_utils_get_window_workspace (GtkWindow *gtkwindow)
 	guint ret = PLUMA_ALL_WORKSPACES;
 
 	g_return_val_if_fail (GTK_IS_WINDOW (gtkwindow), 0);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_return_val_if_fail (gtk_widget_get_realized (GTK_WIDGET (gtkwindow)), 0);
-#else
-	g_return_val_if_fail (GTK_WIDGET_REALIZED (GTK_WIDGET (gtkwindow)), 0);
-#endif
 
 	window = gtk_widget_get_window (GTK_WIDGET (gtkwindow));
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display = gdk_window_get_display (window);
-#else
-	display = gdk_drawable_get_display (window);
-#endif
 
 	gdk_error_trap_push ();
 	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
@@ -1005,14 +989,6 @@ pluma_utils_get_current_viewport (GdkScreen    *screen,
 #endif
 }
 
-void
-pluma_utils_activate_url (GtkAboutDialog *about,
-			  const gchar    *url,
-			  gpointer        data)
-{
-	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (about)), url, GDK_CURRENT_TIME, NULL);
-}
-
 static gboolean
 is_valid_scheme_character (gchar c)
 {
@@ -1404,6 +1380,8 @@ pluma_utils_drop_get_uris (GtkSelectionData *selection_data)
 			uri_list[p++] = uri;
 	}
 
+	g_strfreev (uris);
+
 	if (*uri_list == NULL)
 	{
 		g_free(uri_list);
