@@ -53,10 +53,6 @@
 #include "pluma-marshal.h"
 #include "pluma-utils.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define GTK_WIDGET_VISIBLE gtk_widget_get_visible
-#endif
-
 #define PLUMA_VIEW_SCROLL_MARGIN 0.02
 #define PLUMA_VIEW_SEARCH_DIALOG_TIMEOUT (30*1000) /* 30 seconds */
 
@@ -108,11 +104,7 @@ struct _PlumaViewPrivate
 /* The search entry completion is shared among all the views */
 GtkListStore *search_completion_model = NULL;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void	pluma_view_dispose		(GObject          *object);
-#else
-static void	pluma_view_destroy		(GtkObject        *object);
-#endif
 static void	pluma_view_finalize		(GObject          *object);
 static gint     pluma_view_focus_out		(GtkWidget        *widget,
 						 GdkEventFocus    *event);
@@ -198,19 +190,12 @@ static void
 pluma_view_class_init (PlumaViewClass *klass)
 {
 	GObjectClass     *object_class = G_OBJECT_CLASS (klass);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	GtkObjectClass   *gtkobject_class = GTK_OBJECT_CLASS (klass);
-#endif
 	GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkTextViewClass *text_view_class = GTK_TEXT_VIEW_CLASS (klass);
 	
 	GtkBindingSet    *binding_set;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	object_class->dispose = pluma_view_dispose;
-#else
-	gtkobject_class->destroy = pluma_view_destroy;
-#endif
 	object_class->finalize = pluma_view_finalize;
 
 	widget_class->focus_out_event = pluma_view_focus_out;
@@ -419,11 +404,7 @@ pluma_view_init (PlumaView *view)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 pluma_view_dispose (GObject *object)
-#else
-pluma_view_destroy (GtkObject *object)
-#endif
 {
 	PlumaView *view;
 
@@ -448,11 +429,7 @@ pluma_view_destroy (GtkObject *object)
 	current_buffer_removed (view);
 	g_signal_handlers_disconnect_by_func (view, on_notify_buffer_cb, NULL);
 	
-#if GTK_CHECK_VERSION (3, 0, 0)
 	(* G_OBJECT_CLASS (pluma_view_parent_class)->dispose) (object);
-#else
-	(* GTK_OBJECT_CLASS (pluma_view_parent_class)->destroy) (object);
-#endif
 }
 
 static void
@@ -939,19 +916,8 @@ send_focus_change (GtkWidget *widget,
 
 	g_object_ref (widget);
 
-#if !GTK_CHECK_VERSION (2, 21, 0)
-	if (in)
-		GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
-	else
-		GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
-#endif
-
 	fevent->focus_change.type = GDK_FOCUS_CHANGE;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	fevent->focus_change.window = g_object_ref (gtk_widget_get_window (widget));
-#else
-	fevent->focus_change.window = g_object_ref (widget->window);
-#endif
 	fevent->focus_change.in = in;
   
 	gtk_widget_event (widget, fevent);
@@ -1018,11 +984,7 @@ update_search_window_position (PlumaView *view)
 {
 	gint x, y;
 	gint view_x, view_y;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GdkWindow *view_window = gtk_widget_get_window (GTK_WIDGET (view));
-#else
-	GdkWindow *view_window = GTK_WIDGET (view)->window;
-#endif
 
 	gtk_widget_realize (view->priv->search_window);
 
@@ -1498,15 +1460,9 @@ ensure_search_window (PlumaView *view)
 	GtkWindowGroup     *search_group;
 	
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (view));
-#if GTK_CHECK_VERSION (3, 0, 0)
 	group = gtk_window_get_group (GTK_WINDOW (toplevel));
 	if (view->priv->search_window != NULL)
 		search_group = gtk_window_get_group (GTK_WINDOW (view->priv->search_window));
-#else
-	group = GTK_WINDOW (toplevel)->group;
-	if (view->priv->search_window != NULL)
-		search_group = GTK_WINDOW (view->priv->search_window)->group;
-#endif
 
 	if (view->priv->search_window != NULL)
 	{
@@ -1820,14 +1776,10 @@ start_interactive_search_real (PlumaView *view)
 	GtkTextBuffer *buffer;
 	
 	if ((view->priv->search_window != NULL) &&
-	    GTK_WIDGET_VISIBLE (view->priv->search_window))
+	    gtk_widget_get_visible (view->priv->search_window))
 		return TRUE;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	if (!gtk_widget_has_focus (view))
-#else
-	if (!GTK_WIDGET_HAS_FOCUS (view))
-#endif
 		return FALSE;
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -1981,11 +1933,7 @@ pluma_view_drag_motion (GtkWidget      *widget,
 	if (drag_get_uri_target (widget, context) != GDK_NONE) 
 	{
 		gdk_drag_status (context,
-#if GTK_CHECK_VERSION (3, 0, 0)
 				 gdk_drag_context_get_suggested_action (context),
-#else
-				 context->suggested_action,
-#endif
 				 timestamp);
 		result = TRUE;
 	}
@@ -2189,11 +2137,7 @@ delete_line (GtkTextView *text_view,
 
 	buffer = gtk_text_view_get_buffer (text_view);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_text_view_reset_im_context (text_view);
-#else
-	reset_im_context (text_view);
-#endif
 
 	/* If there is a selection delete the selected lines and
 	 * ignore count */
